package com.example.nto.service.impl;

import com.example.nto.dto.EmployeeDTO;
import com.example.nto.dto.RegisterDTO;
import com.example.nto.entity.Employee;
import com.example.nto.exceptions.EmployeeAlreadyExistException;
import com.example.nto.exceptions.EmployeeNotFoundException;
import com.example.nto.repository.EmployeeRepository;
import com.example.nto.service.EmployeeService;
import com.example.nto.util.EmployeeMapper;
import lombok.AllArgsConstructor;
import org.springframework.security.crypto.password.PasswordEncoder;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.Optional;

@Service
@AllArgsConstructor
public class EmployeeServiceImpl implements EmployeeService {

    private EmployeeRepository repository;
    private final PasswordEncoder passwordEncoder;

    @Override
    public void updateLocalTime(Employee employee) {
        employee.setLastVisit(LocalDateTime.now().toString());
        repository.save(employee);
    }

    @Override
    public Employee findEmployeeByUsername(String login) {

        return repository.findEmployeeByUsername(login).orElseThrow(() -> new EmployeeNotFoundException("Employee with username "+login+" not found"));
    }

    public EmployeeDTO findEmployeeDTOByUsername(String login) {

        return EmployeeMapper.convertToDTO(repository.findEmployeeByUsername(login).orElseThrow(() -> new EmployeeNotFoundException("Employee with username "+login+" not found")));
    }

    @Override
    public EmployeeDTO createEmployee(RegisterDTO dto) {

        Optional<Employee> optionalEmployee = repository.findEmployeeByUsername(dto.getUsername());
        if(optionalEmployee.isPresent()){
            throw new EmployeeAlreadyExistException("Employee with username " + dto.getUsername() +" already exist");
        }

        Employee employee = new Employee();
        employee.setName(dto.getName());
        employee.setUsername(dto.getUsername());

        // Encoding password
        employee.setPassword(passwordEncoder.encode(dto.getPassword()));

        employee.setPhoto(dto.getPhoto());
        employee.setJobPos(dto.getJobPos());
        employee.setLastVisit(LocalDateTime.now().toString());

        return EmployeeMapper.convertToDTO(repository.save(employee));
    }


}

